Parity

Enum Parity 

pub enum Parity {
    None,
    Even,
    Odd,
}
Parity check

Parity is a form of error detection in UART communication, used to ensure that the data has not been corrupted during transmission. The parity bit is added to the data bits to make the number of 1-bits either even or odd.

Variants



None

No parity bit is used.



Even

Even parity: the parity bit is set to make the total number of 1-bits even.



Odd

Odd parity: the parity bit is set to make the total number of 1-bits odd.